<!--
SPDX-FileCopyrightText: 2022 Contributors to the rez project

SPDX-License-Identifier: Apache-2.0
-->

# Code of Conduct
The rez-pip project abides by rez's code of conduct, which you can read in full [here](https://github.com/AcademySoftwareFoundation/rez/blob/main/CODE_OF_CONDUCT.md).
